@@ -109,7 +109,6 @@ class Player(GObject.GObject):
         self.playlistField = None
         self.currentTrack = None
         self.currentTrackUri = None
-        self._lastState = Gst.State.PAUSED
         scale = parent_window.get_scale_factor()
         self.cache = AlbumArtCache(scale)
         self._loading_icon_surface = DefaultIcon(scale).get(
@@ -266,7 +265,7 @@ class Player(GObject.GObject):
         install_ctx = GstPbutils.InstallPluginsContext.new()
 
         if self._gst_plugins_base_check_version(1, 5, 0):
-            install_ctx.set_desktop_id('gnome-music.desktop')
+            install_ctx.set_desktop_id('org.gnome.Music.desktop')
             install_ctx.set_confirm_search(confirm_search)
 
             startup_id = '_TIME%u' % Gtk.get_current_event_time()
@@ -750,8 +749,11 @@ class Player(GObject.GObject):
         else:
             self.set_playing(True)
 
+    # FIXME: set the discovery field to 11 to be safe, but for some
+    # models it is 12.
     @log
-    def set_playlist(self, type, id, model, iter, field, discovery_status_field):
+    def set_playlist(self, type, id, model, iter, field,
+                     discovery_status_field=11):
         self.stop()
 
         old_playlist = self.playlist
@@ -821,15 +823,42 @@ class Player(GObject.GObject):
         self.progressScale.connect('button-press-event', self._on_progress_scale_event)
         self.progressScale.connect('value-changed', self._on_progress_value_changed)
         self.progressScale.connect('button-release-event', self._on_progress_scale_button_released)
+        self.progressScale.connect('change-value', self._on_progress_scale_seek)
         self._ps_draw = self.progressScale.connect('draw',
             self._on_progress_scale_draw)
+        self._seek_timeout = None
+        self._old_progress_scale_value = 0.0
+
+    def _on_progress_scale_seek_finish(self, value):
+        """Prevent stutters when seeking with infinitesimal amounts"""
+        self._seek_timeout = None
+        round_digits = self.progressScale.get_property('round-digits')
+        if self._old_progress_scale_value != round(value, round_digits):
+            self.on_progress_scale_change_value(self.progressScale)
+        return False
+
+    def _on_progress_scale_seek(self, scale, scroll_type, value):
+        """Smooths out the seeking process
+
+        Called every time progress scale is moved. Only after a seek has been
+        stable for 100ms, we play the song from its location.
+        """
+        if self._seek_timeout:
+            GLib.source_remove(self._seek_timeout)
+
+        Gtk.Range.do_change_value(scale, scroll_type, value)
+        self._seek_timeout = GLib.timeout_add(100,
+                                              self._on_progress_scale_seek_finish,
+                                              value)
+        return True
 
     @log
     def _on_progress_scale_button_released(self, scale, data):
-        self.on_progress_scale_change_value(self.progressScale)
+        if self._seek_timeout:
+            GLib.source_remove(self._seek_timeout)
+            self._on_progress_scale_seek_finish(self.progressScale.get_value())
+
         self._update_position_callback()
-        self.player.set_state(self._lastState)
-        self._update_timeout()
         return False
 
     def _on_progress_value_changed(self, widget):
@@ -839,9 +868,8 @@ class Player(GObject.GObject):
 
     @log
     def _on_progress_scale_event(self, scale, data):
-        self._lastState = self.player.get_state(1)[1]
-        self.player.set_state(Gst.State.PAUSED)
         self._remove_timeout()
+        self._old_progress_scale_value = self.progressScale.get_value()
         return False
 
     def _on_progress_scale_draw(self, cr, data):
